Glossary
--------

.. glossary::

   Dictionary
       A mapping from a set of keys to their corresponding values.

   Hashtable
       The algorithm used to implement Python dictionaries.

   Hash function
       A function used by a hashtable to compute the location for a key.

   Histogram
       A set of counters.

   Implementation
       A way of performing a computation.

   Dictionary Item
       Another name for a key-value pair.

   Key
       An object that appears in a dictionary as the first part of a key-value pair.

   Key-value pair
       The representation of the mapping from a key to a value.

   Lookup
       A dictionary operation that takes a key and finds the corresponding value.

   Nested loops
       When there are one or more loops "inside" of another loop. The inner loop runs to completion each time the outer loop runs once.

   Dictionary Value
       An object that appears in a dictionary as the second part of a key-value pair. This is more specific than our previous use of the word "value".

.. dragndrop:: chapter_nine_glossary_one
   :practice: T
   :feedback: Look above for the definitions of these terms.
   :match_1: dictionary|||A mapping from a set of keys to their corresponding values.
   :match_2: hashtable|||The algorithm used to implement Python dictionaries.
   :match_3: hash function|||A function used by a hashtable to compute the location for a key.
   :match_4: histogram|||A set of counters.

   Match each term with its definition.

.. dragndrop:: chapter_nine_glossary_two
   :practice: T
   :feedback: Look above for the definitions of these terms.
   :match_1: implementation|||A way of performing a computation.
   :match_2: item|||Another name for a key-value pair.
   :match_3: key|||An object that appears in a dictionary as the first part of a key-value pair.
   :match_4: key-value pair|||The representation of the mapping from a key to a value.

   Match each term with its definition.

.. dragndrop:: chapter_nine_glossary_three
   :practice: T
   :feedback: Look above for the definitions of these terms.
   :match_1: lookup|||A dictionary operation that takes a key and finds the corresponding value.
   :match_2: nested loops|||When there are one or more loops "inside" of another loop. The inner loop runs to completion each time the outer loop runs once.
   :match_3: value|||An object that appears in a dictionary as the second part of a key-value pair. This is more specific than our previous use of the word "value".

   Match each term with its definition.
